struct VERTEX_IN
{
 float4 position :POSITION;
 float4 texCoord :TEXCOORD0;
 float4 texCoord2 :TEXCOORD1;
 float4 normal   :NORMAL;
};

struct VERTEX_OUT
{
 float4 position :POSITION;
 float4 wPos :TEXCOORD1;
 float4 wN :TEXCOORD2;
 float4 texCoord :TEXCOORD0;
};

VERTEX_OUT vs(VERTEX_IN IN,
	      uniform float4x4 ModelViewProj,
	      uniform float4x4 Model,
	      uniform float4x4 ModelIT)
{
  
  VERTEX_OUT OUT = (VERTEX_OUT) 0;

  OUT.position = mul(ModelViewProj, IN.position);
  OUT.texCoord = float4(IN.texCoord.xy,IN.texCoord2.xy);
  OUT.wPos = mul(Model, IN.position);
  OUT.wN = mul(ModelIT, IN.normal);
  return OUT;
}

float4 ps(VERTEX_OUT IN,
		  uniform float4 light0,
		  uniform float4 light1,		  
          uniform sampler2D colorMap : register(s0),
          uniform sampler2D lightMap : register(s1),
          uniform sampler2D normalMap : register(s2),
          uniform float bumpHeight):COLOR0
{
 float4 color = 1;
 float4 kd = tex2D(colorMap, IN.texCoord.xy);
 float4 lm = tex2D(lightMap, IN.texCoord.zw);

//return kd;

 float3 tN = tex2D(normalMap, IN.texCoord.xy).rgb;
 tN.xy = tN.xy * 2.0 - 1.0;
 tN.z /= bumpHeight;
 tN = normalize(tN);
 
 float facing = dot(tN, float3(0,0,1));
 //facing *= facing;
 
 color = kd * lm * facing;
 

 float3 N = normalize(IN.wN.xyz);
 float3 P = IN.wPos;
 float3 L = light0.xyz - P;
 float d = length(L);
 color += light0.w / d * kd * 10;
 
 L = light1.xyz - P;
 d = length(L);
 L = normalize(L);
 color += light1.w / d * kd * 10;


 //return facing;
 return color;
}